class LearningObject < ActiveRecord::Base
  include Metadatable
  include Reviewable
  include Sociable
  include Stateful

  has_attached_file :thumbnail, styles: {medium: "530x300", small: "250x140"}
  validates_attachment_content_type :thumbnail, :content_type => ["image/jpg", "image/jpeg", "image/png", "image/gif"]
  has_and_belongs_to_many :topics

  has_many :collection_items, as: :collectionable
  has_many :collections, through: :collection_items
  has_many :complaints
  has_many :attachments, class_name: 'LearningObject::Attachment', dependent: :destroy

  belongs_to :publisher, polymorphic: true
  belongs_to :language

  validates_presence_of :name, :id_dspace
  validates_uniqueness_of :id_dspace

  scope :object_types, -> { group(:object_type).count.reject { |type, frequency| type.blank? }.map { |type, frequency| type } }

  searchkick language: 'brazilian', searchable: [:name, :description, :author, :object_type]

  def search_data
    {
        name: name,
        description: description,
        author: author,
        object_type: object_type,
        score: score,
        published_at: published_at,
        # publisher_id: publisher.id,
        topics_name: topics.map(&:name)
    }
  end

  def categories
    get_metadata_value_of 'dc.subject.category'
  end

  def default_attachment
    attachments.where(bundle_name: 'ORIGINAL').first
  end

  def retrieve_link
    "#{DspaceService.link}/rest#{default_attachment.retrieve_link}"
  end

  def url_reference
    get_metadata_value_of 'dc.object.url'
  end

  ##checks if learning object link to an url.
  #returns boolean
  def has_url_reference?
    !url_reference.blank?
  end
end
