require 'dspace'

class LearningObjectPublisher

  def initialize(dspace_client)
    @dspace = dspace_client
  end

  #create a learning object with draft status
  #if draft#type is 'external link', then the draft is published.
  def create_draft(draft)
    item = @dspace.collections.create_item(build_dspace_item(draft), id: DspaceService::TEST_COLLECTION)
    draft.id_dspace = item.id
    draft.save!
    publish! draft if draft.has_url_reference?
    draft
  end

  #post *media_path* to *learning_object* on dspace
  def post(learning_object, media_path)
    DspaceUploadWorker.perform_async learning_object.id, learning_object.id_dspace, media_path, learning_object.description
    ThumbnailGenerateWorker.perform_async media_path, learning_object.id
  end

  ##publish *learning_object*
  #this method will create thumbnails, change state to published and will save it.
  def publish!(learning_object)
    if learning_object.is_draft?
      create_thumbnail! learning_object
      learning_object.publish
    end

    learning_object.save
  end


  def build_dspace_item(draft)
    ::Dspace::Item.new({
                           'name' => draft.name
                       })
  end

end
